==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/FabricCreationInputPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of site details provided during the time of site creation.
 * @property customDetails Fabric provider specific creation input.
 */
public data class FabricCreationInputPropertiesArgs(
    public val customDetails: Output<Any>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs =
        com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs.builder()
            .customDetails(customDetails?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FabricCreationInputPropertiesArgs].
 */
@PulumiTagMarker
public class FabricCreationInputPropertiesArgsBuilder internal constructor() {
    private var customDetails: Output<Any>? = null

    /**
     * @param value Fabric provider specific creation input.
     */
    @JvmName("lcyvhqhietknlefd")
    public suspend fun customDetails(`value`: Output<Any>) {
        this.customDetails = value
    }

    /**
     * @param value Fabric provider specific creation input.
     */
    @JvmName("vvxbkjakkmphgirc")
    public suspend fun customDetails(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customDetails = mapped
    }

    internal fun build(): FabricCreationInputPropertiesArgs = FabricCreationInputPropertiesArgs(
        customDetails = customDetails,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/FabricCreationInputPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of site details provided during the time of site creation.
 * @property customDetails Fabric provider specific creation input.
 */
public data class FabricCreationInputPropertiesArgs(
    public val customDetails: Output<Any>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs =
        com.pulumi.azurenative.recoveryservices.inputs.FabricCreationInputPropertiesArgs.builder()
            .customDetails(customDetails?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FabricCreationInputPropertiesArgs].
 */
@PulumiTagMarker
public class FabricCreationInputPropertiesArgsBuilder internal constructor() {
    private var customDetails: Output<Any>? = null

    /**
     * @param value Fabric provider specific creation input.
     */
    @JvmName("nxmjrdhtkvdcfucc")
    public suspend fun customDetails(`value`: Output<Any>) {
        this.customDetails = value
    }

    /**
     * @param value Fabric provider specific creation input.
     */
    @JvmName("gkklqllbdmxcjyed")
    public suspend fun customDetails(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customDetails = mapped
    }

    internal fun build(): FabricCreationInputPropertiesArgs = FabricCreationInputPropertiesArgs(
        customDetails = customDetails,
    )
}
